::: beignet.add_probabilists_hermite_polynomial
::: beignet.differentiate_probabilists_hermite_polynomial
::: beignet.divide_probabilists_hermite_polynomial
::: beignet.evaluate_probabilists_hermite_polynomial
::: beignet.evaluate_probabilists_hermite_polynomial_2d
::: beignet.evaluate_probabilists_hermite_polynomial_3d
::: beignet.evaluate_probabilists_hermite_polynomial_cartersian_2d
::: beignet.evaluate_probabilists_hermite_polynomial_cartersian_3d
::: beignet.fit_probabilists_hermite_polynomial
::: beignet.integrate_probabilists_hermite_polynomial
::: beignet.linear_probabilists_hermite_polynomial
::: beignet.multiply_probabilists_hermite_polynomial
::: beignet.multiply_probabilists_hermite_polynomial_by_x
::: beignet.probabilists_hermite_polynomial_companion
::: beignet.probabilists_hermite_polynomial_domain
::: beignet.probabilists_hermite_polynomial_from_roots
::: beignet.probabilists_hermite_polynomial_one
::: beignet.probabilists_hermite_polynomial_power
::: beignet.probabilists_hermite_polynomial_roots
::: beignet.probabilists_hermite_polynomial_to_polynomial
::: beignet.probabilists_hermite_polynomial_vandermonde
::: beignet.probabilists_hermite_polynomial_vandermonde_2d
::: beignet.probabilists_hermite_polynomial_vandermonde_3d
::: beignet.probabilists_hermite_polynomial_weight
::: beignet.probabilists_hermite_polynomial_x
::: beignet.probabilists_hermite_polynomial_zero
::: beignet.subtract_probabilists_hermite_polynomial
::: beignet.trim_probabilists_hermite_polynomial_coefficients
